Opens a SQLite database and checks that all required tracking tables are
present. Use init_tracking_db() to create a new database or to add missing
tables to an existing file.
Examples
db_path <- tempfile(fileext = ".sqlite")
con <- init_tracking_db(db_path, overwrite = TRUE)
DBI::dbDisconnect(con)
con <- connect_tracking_db(db_path)
DBI::dbDisconnect(con)